@@ -259,7 +259,7 @@ exports.handler = async function (event, context) {
       "FAILED",
       physicalResourceId,
       null,
-      `${err.message} (Log: ${defaultLogGroup || context.logGroupName}${
+      `${err.message} (Log: ${defaultLogGroup || context.logGroupName}/${
         defaultLogStream || context.logStreamName
       })`
     );
