@@ -10,7 +10,7 @@ describe("Env Controller Handler", () => {
   const nock = require("nock");
   const ResponseURL = "https://cloudwatch-response-mock.example.com/";
   const LogGroup = "/aws/lambda/testLambda";
-  const LogStream = "/2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd";
+  const LogStream = "2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd";
   const testRequestId = "f4ef1b10-c39a-44e3-99c0-fbf7e53c3943";
   let origLog = console.log;
 
