@@ -5,8 +5,11 @@ package cli
 
 import (
 	"errors"
+	"fmt"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
+
 	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
@@ -201,16 +204,91 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 		given     func(ctrl *gomock.Controller) *envUpgradeOpts
 		wantedErr error
 	}{
+		"should return an error if the environment template cannot be updated to grant upload artifacts permissions": {
+			given: func(ctrl *gomock.Controller) *envUpgradeOpts {
+				mockStore := mocks.NewMockstore(ctrl)
+				mockStore.EXPECT().ListEnvironments("phonetool").Return([]*config.Environment{
+					{
+						Name:             "test",
+						App:              "phonetool",
+						Region:           "us-west-2",
+						ExecutionRoleARN: "execRoleARN",
+					},
+				}, nil)
+				mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{Name: "phonetool"}, nil)
+				mockAppCFN := mocks.NewMockappResourcesGetter(ctrl)
+				mockAppCFN.EXPECT().GetAppResourcesByRegion(&config.Application{Name: "phonetool"}, "us-west-2").
+					Return(&stack.AppRegionalResources{
+						S3Bucket: "mockBucket",
+					}, nil)
+
+				mockProg := mocks.NewMockprogress(ctrl)
+				mockProg.EXPECT().Start(gomock.Any())
+				mockProg.EXPECT().Stop(gomock.Any())
+
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", "test").Return(`
+Metadata:
+  Version: v1.7.0
+Resources:
+  EnvironmentManagerRole:
+    Properties:
+      Policies:
+        - PolicyDocument:
+            Statement:
+            - Sid: CloudwatchLogs 
+  OtherResource:
+`, nil)
+				mockEnvDeployer.EXPECT().UpdateEnvironmentTemplate("phonetool", "test", `
+Metadata:
+  Version: v1.7.0
+Resources:
+  EnvironmentManagerRole:
+    Properties:
+      Policies:
+        - PolicyDocument:
+            Statement:
+            - Sid: PatchPutObjectsToArtifactBucket
+              Effect: Allow
+              Action:
+                - s3:PutObject
+                - s3:PutObjectAcl
+              Resource:
+                - arn:aws:s3:::mockBucket
+                - arn:aws:s3:::mockBucket/*
+            - Sid: CloudwatchLogs 
+  OtherResource:
+`, "execRoleARN").Return(errors.New("some unexpected error"))
+				return &envUpgradeOpts{
+					envUpgradeVars: envUpgradeVars{
+						appName: "phonetool",
+						all:     true,
+					},
+					store:  mockStore,
+					prog:   mockProg,
+					appCFN: mockAppCFN,
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
+						return mocks.NewMockuploader(ctrl), nil
+					},
+				}
+			},
+			wantedErr: errors.New("update environment template with PutObject permissions: some unexpected error"),
+		},
 		"should skip upgrading if the environment version is already at least latest": {
 			given: func(ctrl *gomock.Controller) *envUpgradeOpts {
 				mockStore := mocks.NewMockstore(ctrl)
 				mockStore.EXPECT().ListEnvironments("phonetool").Return([]*config.Environment{
 					{
 						Name:   "test",
+						App:    "phonetool",
 						Region: "us-west-2",
 					},
 					{
 						Name:   "prod",
+						App:    "phonetool",
 						Region: "us-east-1",
 					},
 				}, nil)
@@ -224,6 +302,13 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					Return(&stack.AppRegionalResources{
 						S3Bucket: "mockBucket",
 					}, nil)
+
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", gomock.Any()).Return(`
+Metadata:
+  Version: v1.9.0
+`, nil).Times(2)
+
 				mockUploader := mocks.NewMockcustomResourcesUploader(ctrl)
 				mockUploader.EXPECT().UploadEnvironmentCustomResources(gomock.Any()).Return(nil, nil).Times(2)
 				mockEnvTpl := mocks.NewMockversionGetter(ctrl)
@@ -240,20 +325,23 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					},
 					uploader: mockUploader,
 					appCFN:   mockAppCFN,
-					newS3: func(region string) (uploader, error) {
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
 						return mocks.NewMockuploader(ctrl), nil
 					},
 				}
 			},
 		},
-		"should upgrade non-legacy environments with UpgradeEnvironment call": {
+		"should upgrade non-legacy environments and ignore ErrChangeSet if the environment template already has permissions to upload artifacts": {
 			given: func(ctrl *gomock.Controller) *envUpgradeOpts {
 				mockEnvTpl := mocks.NewMockversionGetter(ctrl)
 				mockEnvTpl.EXPECT().Version().Return("v0.1.0", nil) // Legacy versions are v0.0.0
 
 				mockProg := mocks.NewMockprogress(ctrl)
-				mockProg.EXPECT().Start(gomock.Any())
-				mockProg.EXPECT().Stop(gomock.Any())
+				mockProg.EXPECT().Start(gomock.Any()).AnyTimes()
+				mockProg.EXPECT().Stop(gomock.Any()).AnyTimes()
 
 				mockStore := mocks.NewMockstore(ctrl)
 				mockStore.EXPECT().GetEnvironment("phonetool", "test").
@@ -278,6 +366,27 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 						S3Bucket:  "mockBucket",
 						KMSKeyARN: "mockKMS",
 					}, nil)
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", "test").Return(`
+Metadata:
+  Version: v1.1.0
+Resources:
+  EnvironmentManagerRole:
+    Properties:
+      Policies:
+        - PolicyDocument:
+            Statement:
+            - Sid: PatchPutObjectsToArtifactBucket
+              Effect: Allow
+              Action:
+                - s3:PutObject
+                - s3:PutObjectAcl
+              Resource:
+                - arn:aws:s3:::mockBucket
+                - arn:aws:s3:::mockBucket/*
+`, nil)
+				mockEnvDeployer.EXPECT().UpdateEnvironmentTemplate(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).Return(fmt.Errorf("wrapped err: %w", &cloudformation.ErrChangeSetEmpty{}))
+
 				mockUploader := mocks.NewMockcustomResourcesUploader(ctrl)
 				mockUploader.EXPECT().UploadEnvironmentCustomResources(gomock.Any()).Return(map[string]string{"mockCustomResource": "mockURL"}, nil)
 
@@ -315,7 +424,10 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					},
 					uploader: mockUploader,
 					appCFN:   mockAppCFN,
-					newS3: func(region string) (uploader, error) {
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
 						return mocks.NewMockuploader(ctrl), nil
 					},
 				}
@@ -357,6 +469,13 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 						S3Bucket:  "mockBucket",
 						KMSKeyARN: "mockKMS",
 					}, nil)
+
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", "test").Return(`
+Metadata:
+  Version: v1.9.0
+`, nil)
+
 				mockUploader := mocks.NewMockcustomResourcesUploader(ctrl)
 				mockUploader.EXPECT().UploadEnvironmentCustomResources(gomock.Any()).Return(map[string]string{"mockCustomResource": "mockURL"}, nil)
 
@@ -393,7 +512,10 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					},
 					uploader: mockUploader,
 					appCFN:   mockAppCFN,
-					newS3: func(region string) (uploader, error) {
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
 						return mocks.NewMockuploader(ctrl), nil
 					},
 				}
@@ -428,6 +550,12 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					Return(&stack.AppRegionalResources{
 						S3Bucket: "mockBucket",
 					}, nil)
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", "test").Return(`
+Metadata:
+  Version: v1.9.0
+`, nil)
+
 				mockUploader := mocks.NewMockcustomResourcesUploader(ctrl)
 				mockUploader.EXPECT().UploadEnvironmentCustomResources(gomock.Any()).Return(nil, nil)
 
@@ -464,7 +592,10 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					},
 					uploader: mockUploader,
 					appCFN:   mockAppCFN,
-					newS3: func(region string) (uploader, error) {
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
 						return mocks.NewMockuploader(ctrl), nil
 					},
 				}
@@ -494,6 +625,13 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					Return(&stack.AppRegionalResources{
 						S3Bucket: "mockBucket",
 					}, nil)
+
+				mockEnvDeployer := mocks.NewMockenvironmentDeployer(ctrl)
+				mockEnvDeployer.EXPECT().EnvironmentTemplate("phonetool", "test").Return(`
+Metadata:
+  Version: v1.9.0
+`, nil)
+
 				mockUploader := mocks.NewMockcustomResourcesUploader(ctrl)
 				mockUploader.EXPECT().UploadEnvironmentCustomResources(gomock.Any()).Return(nil, nil)
 
@@ -520,7 +658,10 @@ func TestEnvUpgradeOpts_Execute(t *testing.T) {
 					},
 					uploader: mockUploader,
 					appCFN:   mockAppCFN,
-					newS3: func(region string) (uploader, error) {
+					newEnvDeployer: func(_ *config.Environment) (environmentDeployer, error) {
+						return mockEnvDeployer, nil
+					},
+					newS3: func(_ *config.Environment) (uploader, error) {
 						return mocks.NewMockuploader(ctrl), nil
 					},
 				}
