@@ -6,30 +6,29 @@ package cli
 import (
 	"encoding"
 	"io"
-	"time"
 
-	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
-
-	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
-
-	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
-
-	"github.com/aws/copilot-cli/internal/pkg/aws/ssm"
+	"github.com/aws/copilot-cli/internal/pkg/aws/secretsmanager"
 
 	"github.com/aws/aws-sdk-go/aws/session"
 	awscloudformation "github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/codepipeline"
+	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 	awsecs "github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/aws/s3"
+	"github.com/aws/copilot-cli/internal/pkg/aws/ssm"
+	clideploy "github.com/aws/copilot-cli/internal/pkg/cli/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/describe"
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
 	"github.com/aws/copilot-cli/internal/pkg/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/exec"
 	"github.com/aws/copilot-cli/internal/pkg/initialize"
 	"github.com/aws/copilot-cli/internal/pkg/logging"
+	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/repository"
 	"github.com/aws/copilot-cli/internal/pkg/task"
 	termprogress "github.com/aws/copilot-cli/internal/pkg/term/progress"
@@ -143,6 +142,7 @@ type store interface {
 type deployedEnvironmentLister interface {
 	ListEnvironmentsDeployedTo(appName, svcName string) ([]string, error)
 	ListDeployedServices(appName, envName string) ([]string, error)
+	ListDeployedJobs(appName string, envName string) ([]string, error)
 	IsServiceDeployed(appName, envName string, svcName string) (bool, error)
 	ListSNSTopics(appName string, envName string) ([]deploy.Topic, error)
 }
@@ -159,6 +159,7 @@ type secretCreator interface {
 }
 
 type secretDeleter interface {
+	DescribeSecret(secretName string) (*secretsmanager.DescribeSecretOutput, error)
 	DeleteSecret(secretName string) error
 }
 
@@ -167,7 +168,7 @@ type imageBuilderPusher interface {
 }
 
 type repositoryURIGetter interface {
-	URI() string
+	URI() (string, error)
 }
 
 type repositoryService interface {
@@ -183,11 +184,6 @@ type templater interface {
 	Template() (string, error)
 }
 
-type stackSerializer interface {
-	templater
-	SerializedParameters() (string, error)
-}
-
 type runner interface {
 	Run(name string, args []string, options ...exec.CmdOption) error
 }
@@ -241,12 +237,14 @@ type workspacePathGetter interface {
 }
 
 type wsPipelineManifestReader interface {
-	ReadPipelineManifest() ([]byte, error)
+	ReadPipelineManifest(path string) (*manifest.Pipeline, error)
 }
 
-type wsPipelineWriter interface {
-	WritePipelineBuildspec(marshaler encoding.BinaryMarshaler) (string, error)
-	WritePipelineManifest(marshaler encoding.BinaryMarshaler) (string, error)
+type wsPipelineIniter interface {
+	WritePipelineBuildspec(marshaler encoding.BinaryMarshaler, name string) (string, error)
+	WritePipelineManifest(marshaler encoding.BinaryMarshaler, name string) (string, error)
+	Rel(path string) (string, error)
+	ListPipelines() ([]workspace.PipelineManifest, error)
 }
 
 type serviceLister interface {
@@ -258,11 +256,6 @@ type wsSvcReader interface {
 	manifestReader
 }
 
-type wsSvcDirReader interface {
-	wsSvcReader
-	workspacePathGetter
-}
-
 type jobLister interface {
 	ListJobs() ([]string, error)
 }
@@ -291,8 +284,14 @@ type wsWlDirReader interface {
 }
 
 type wsPipelineReader interface {
+	wsPipelineGetter
+	Rel(path string) (string, error)
+}
+
+type wsPipelineGetter interface {
 	wsPipelineManifestReader
 	wlLister
+	ListPipelines() ([]workspace.PipelineManifest, error)
 }
 
 type wsAppManager interface {
@@ -350,7 +349,7 @@ type pipelineDeployer interface {
 	CreatePipeline(env *deploy.CreatePipelineInput, bucketName string) error
 	UpdatePipeline(env *deploy.CreatePipelineInput, bucketName string) error
 	PipelineExists(env *deploy.CreatePipelineInput) (bool, error)
-	DeletePipeline(pipelineName string) error
+	DeletePipeline(pipeline deploy.Pipeline) error
 	AddPipelineResourcesToApp(app *config.Application, region string) error
 	appResourcesGetter
 	// TODO: Add StreamPipelineCreation method
@@ -420,10 +419,6 @@ type versionGetter interface {
 	Version() (string, error)
 }
 
-type endpointGetter interface {
-	ServiceDiscoveryEndpoint() (string, error)
-}
-
 type envTemplater interface {
 	EnvironmentTemplate(appName, envName string) (string, error)
 }
@@ -448,8 +443,10 @@ type appUpgrader interface {
 
 type pipelineGetter interface {
 	GetPipeline(pipelineName string) (*codepipeline.Pipeline, error)
-	ListPipelineNamesByTags(tags map[string]string) ([]string, error)
-	GetPipelinesByTags(tags map[string]string) ([]*codepipeline.Pipeline, error)
+}
+
+type deployedPipelineLister interface {
+	ListDeployedPipelines(appName string) ([]deploy.Pipeline, error)
 }
 
 type executor interface {
@@ -481,10 +478,19 @@ type deploySelector interface {
 	DeployedService(prompt, help string, app string, opts ...selector.GetDeployedServiceOpts) (*selector.DeployedService, error)
 }
 
-type pipelineSelector interface {
+type pipelineEnvSelector interface {
 	Environments(prompt, help, app string, finalMsgFunc func(int) prompt.PromptConfig) ([]string, error)
 }
 
+type wsPipelineSelector interface {
+	WsPipeline(prompt, help string) (*workspace.PipelineManifest, error)
+}
+
+type codePipelineSelector interface {
+	appSelector
+	DeployedPipeline(prompt, help, app string) (deploy.Pipeline, error)
+}
+
 type wsSelector interface {
 	appEnvSelector
 	Service(prompt, help string) (string, error)
@@ -543,17 +549,8 @@ type serviceDescriber interface {
 	DescribeService(app, env, svc string) (*ecs.ServiceDesc, error)
 }
 
-type svcForceUpdater interface {
-	ForceUpdateService(app, env, svc string) error
-	LastUpdatedAt(app, env, svc string) (time.Time, error)
-}
-
-type serviceDeployer interface {
-	DeployService(out termprogress.FileWriter, conf cloudformation.StackConfiguration, bucketName string, opts ...awscloudformation.StackOption) error
-}
-
 type apprunnerServiceDescriber interface {
-	ServiceARN() (string, error)
+	ServiceARN(env string) (string, error)
 }
 
 type ecsCommandExecutor interface {
@@ -618,11 +615,18 @@ type servicePauser interface {
 	PauseService(svcARN string) error
 }
 
-type timeoutError interface {
-	error
-	Timeout() bool
-}
-
 type interpolator interface {
 	Interpolate(s string) (string, error)
 }
+
+type workloadDeployer interface {
+	UploadArtifacts() (*clideploy.UploadArtifactsOutput, error)
+	DeployWorkload(in *clideploy.DeployWorkloadInput) (clideploy.ActionRecommender, error)
+	IsServiceAvailableInRegion(region string) (bool, error)
+}
+
+type workloadTemplateGenerator interface {
+	UploadArtifacts() (*clideploy.UploadArtifactsOutput, error)
+	GenerateCloudFormationTemplate(in *clideploy.GenerateCloudFormationTemplateInput) (
+		*clideploy.GenerateCloudFormationTemplateOutput, error)
+}
