@@ -7,6 +7,10 @@ import (
 	"errors"
 	"fmt"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/ssm"
+	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
+
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
 
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
@@ -67,27 +71,28 @@ type initJobOpts struct {
 	manifestPath string
 	platform     *manifest.PlatformString
 
+	// For workspace validation.
+	wsPendingCreation bool
+	wsAppName         string
+
 	// Init a Dockerfile parser using fs and input path
 	initParser func(string) dockerfileParser
 }
 
 func newInitJobOpts(vars initJobVars) (*initJobOpts, error) {
-	store, err := config.NewStore()
-	if err != nil {
-		return nil, fmt.Errorf("couldn't connect to config store: %w", err)
-	}
-
 	ws, err := workspace.New()
 	if err != nil {
 		return nil, fmt.Errorf("workspace cannot be created: %w", err)
 	}
 
-	p := sessions.NewProvider()
+	p := sessions.ImmutableProvider(sessions.UserAgentExtras("job init"))
 	sess, err := p.Default()
-	fs := &afero.Afero{Fs: afero.NewOsFs()}
 	if err != nil {
 		return nil, err
 	}
+	store := config.NewSSMStore(identity.New(sess), ssm.New(sess), aws.StringValue(sess.Config.Region))
+
+	fs := &afero.Afero{Fs: afero.NewOsFs()}
 
 	jobInitter := &initialize.WorkloadInitializer{
 		Store:    store,
@@ -112,26 +117,18 @@ func newInitJobOpts(vars initJobVars) (*initJobOpts, error) {
 		initParser: func(path string) dockerfileParser {
 			return dockerfile.New(fs, path)
 		},
+		wsAppName: tryReadingAppName(),
 	}, nil
 }
 
 // Validate returns an error if the flag values passed by the user are invalid.
 func (o *initJobOpts) Validate() error {
-	if o.appName == "" {
-		return errNoAppInWorkspace
-	}
-	if o.wkldType != "" {
-		if err := validateJobType(o.wkldType); err != nil {
-			return err
-		}
-	}
-	if o.name != "" {
-		if err := validateJobName(o.name); err != nil {
-			return err
-		}
-		if err := o.validateDuplicateJob(); err != nil {
+	// If this app is pending creation, we'll skip validation.
+	if !o.wsPendingCreation {
+		if err := validateWorkspaceApp(o.wsAppName, o.appName, o.store); err != nil {
 			return err
 		}
+		o.appName = o.wsAppName
 	}
 	if o.dockerfilePath != "" && o.image != "" {
 		return fmt.Errorf("--%s and --%s cannot be specified together", dockerFileFlag, imageFlag)
@@ -141,11 +138,6 @@ func (o *initJobOpts) Validate() error {
 			return err
 		}
 	}
-	if o.schedule != "" {
-		if err := validateSchedule(o.schedule); err != nil {
-			return err
-		}
-	}
 	if o.timeout != "" {
 		if err := validateTimeout(o.timeout); err != nil {
 			return err
@@ -159,7 +151,24 @@ func (o *initJobOpts) Validate() error {
 
 // Ask prompts for fields that are required but not passed in.
 func (o *initJobOpts) Ask() error {
-	if err := o.askJobName(); err != nil {
+	if o.wkldType != "" {
+		if err := validateJobType(o.wkldType); err != nil {
+			return err
+		}
+	} else {
+		if err := o.askJobType(); err != nil {
+			return err
+		}
+	}
+	if o.name == "" {
+		if err := o.askJobName(); err != nil {
+			return err
+		}
+	}
+	if err := validateJobName(o.name); err != nil {
+		return err
+	}
+	if err := o.validateDuplicateJob(); err != nil {
 		return err
 	}
 	localMft, err := o.mftReader.ReadWorkloadManifest(o.name)
@@ -168,7 +177,9 @@ func (o *initJobOpts) Ask() error {
 		if err != nil {
 			return fmt.Errorf(`read "type" field for job %s from local manifest: %w`, o.name, err)
 		}
-		o.wkldType = jobType
+		if o.wkldType != jobType {
+			return fmt.Errorf("manifest file for job %s exists with a different type %s", o.name, jobType)
+		}
 		log.Infof("Manifest file for job %s already exists. Skipping configuration.\n", o.name)
 		return nil
 	}
@@ -179,9 +190,6 @@ func (o *initJobOpts) Ask() error {
 	if !errors.As(err, &errNotFound) && !errors.As(err, &errWorkspaceNotFound) {
 		return fmt.Errorf("read manifest file for job %s: %w", o.name, err)
 	}
-	if err := o.askJobType(); err != nil {
-		return err
-	}
 	dfSelected, err := o.askDockerfile()
 	if err != nil {
 		return err
@@ -191,7 +199,12 @@ func (o *initJobOpts) Ask() error {
 			return err
 		}
 	}
-	if err := o.askSchedule(); err != nil {
+	if o.schedule == "" {
+		if err := o.askSchedule(); err != nil {
+			return err
+		}
+	}
+	if err := validateSchedule(o.schedule); err != nil {
 		return err
 	}
 	return nil
@@ -299,7 +312,7 @@ func (o *initJobOpts) askJobName() error {
 		return fmt.Errorf("get job name: %w", err)
 	}
 	o.name = name
-	return o.validateDuplicateJob()
+	return nil
 }
 
 func (o *initJobOpts) askImage() error {
@@ -353,9 +366,6 @@ func (o *initJobOpts) askDockerfile() (isDfSelected bool, err error) {
 }
 
 func (o *initJobOpts) askSchedule() error {
-	if o.schedule != "" {
-		return nil
-	}
 	schedule, err := o.sel.Schedule(
 		jobInitSchedulePrompt,
 		jobInitScheduleHelp,
