@@ -10,15 +10,14 @@ import (
 	"time"
 
 	"github.com/aws/copilot-cli/internal/pkg/config"
-	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
-	"github.com/aws/copilot-cli/internal/pkg/workspace"
-
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
+	"github.com/aws/copilot-cli/internal/pkg/term/color"
+	"github.com/aws/copilot-cli/internal/pkg/workspace"
 
 	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/initialize"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
-	"github.com/aws/copilot-cli/internal/pkg/term/color"
 	"github.com/golang/mock/gomock"
 	"github.com/spf13/afero"
 	"github.com/stretchr/testify/require"
@@ -40,115 +39,103 @@ func TestJobInitOpts_Validate(t *testing.T) {
 		inImage          string
 		inTimeout        string
 		inRetries        int
-		inSchedule       string
 
+		setupMocks     func(mocks initJobMocks)
 		mockFileSystem func(mockFS afero.Fs)
 		wantedErr      error
 	}{
-		"invalid app name": {
-			inAppName: "",
-			wantedErr: errNoAppInWorkspace,
+		"fail if using different app name with the workspace": {
+			inAppName: "demo",
+			wantedErr: fmt.Errorf("cannot specify app demo because the workspace is already registered with app phonetool"),
 		},
-		"invalid job name": {
-			inAppName: "phonetool",
-			inJobName: "1234",
-			wantedErr: fmt.Errorf("job name 1234 is invalid: %s", errValueBadFormat),
+		"fail if cannot validate application": {
+			inAppName:        "phonetool",
+			inDockerfilePath: "mockDockerfile",
+			inImage:          "mockImage",
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(nil, errors.New("some error"))
+			},
+			wantedErr: fmt.Errorf("get application phonetool configuration: some error"),
 		},
 		"invalid dockerfile directory path": {
 			inAppName:        "phonetool",
 			inDockerfilePath: "./hello/Dockerfile",
-			wantedErr:        errors.New("open hello/Dockerfile: file does not exist"),
-		},
-		"invalid schedule; not cron": {
-			inAppName:  "phonetool",
-			inSchedule: "every 56 minutes",
-			wantedErr:  fmt.Errorf("schedule every 56 minutes is invalid: %s", errScheduleInvalid),
-		},
-		"invalid schedule; cron interval in subseconds": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 75.9s",
-			wantedErr:  fmt.Errorf("interval @every 75.9s is invalid: %s", errDurationBadUnits),
-		},
-		"invalid schedule; cron interval in milliseconds": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 3ms",
-			wantedErr:  fmt.Errorf("interval @every 3ms is invalid: %s", errDurationBadUnits),
-		},
-		"invalid schedule; cron interval too frequent": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 30s",
-			wantedErr:  errors.New("interval @every 30s is invalid: duration must be 1m0s or greater"),
-		},
-		"invalid schedule; cron interval is zero": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 0s",
-			wantedErr:  errors.New("interval @every 0s is invalid: duration must be 1m0s or greater"),
-		},
-		"invalid schedule; cron interval duration improperly formed": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 5min",
-			wantedErr:  errors.New("interval @every 5min must include a valid Go duration string (example: @every 1h30m)"),
-		},
-		"valid schedule; crontab": {
-			inAppName:  "phonetool",
-			inSchedule: "* * * * *",
-			wantedErr:  nil,
-		},
-		"valid schedule; predefined schedule": {
-			inAppName:  "phonetool",
-			inSchedule: "@daily",
-			wantedErr:  nil,
-		},
-		"valid schedule; interval": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 5m",
-			wantedErr:  nil,
-		},
-		"valid schedule; interval with 0 for some units": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 1h0m0s",
-			wantedErr:  nil,
-		},
-		"valid schedule; interval with carryover value for some units": {
-			inAppName:  "phonetool",
-			inSchedule: "@every 0h60m60s",
-			wantedErr:  nil,
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
+			wantedErr: errors.New("open hello/Dockerfile: file does not exist"),
 		},
 		"invalid timeout duration; incorrect format": {
 			inAppName: "phonetool",
 			inTimeout: "30 minutes",
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
 			wantedErr: fmt.Errorf("timeout value 30 minutes is invalid: %s", errDurationInvalid),
 		},
 		"invalid timeout duration; subseconds": {
 			inAppName: "phonetool",
 			inTimeout: "30m45.5s",
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
 			wantedErr: fmt.Errorf("timeout value 30m45.5s is invalid: %s", errDurationBadUnits),
 		},
 		"invalid timeout duration; milliseconds": {
 			inAppName: "phonetool",
 			inTimeout: "3ms",
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
 			wantedErr: fmt.Errorf("timeout value 3ms is invalid: %s", errDurationBadUnits),
 		},
 		"invalid timeout; too short": {
 			inAppName: "phonetool",
 			inTimeout: "0s",
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
 			wantedErr: errors.New("timeout value 0s is invalid: duration must be 1s or greater"),
 		},
 		"invalid number of times to retry": {
 			inAppName: "phonetool",
 			inRetries: -3,
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
 			wantedErr: errors.New("number of retries must be non-negative"),
 		},
 		"fail if both image and dockerfile are set": {
 			inAppName:        "phonetool",
 			inDockerfilePath: "mockDockerfile",
 			inImage:          "mockImage",
-			wantedErr:        fmt.Errorf("--dockerfile and --image cannot be specified together"),
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetApplication("phonetool").Return(&config.Application{}, nil)
+			},
+			wantedErr: fmt.Errorf("--dockerfile and --image cannot be specified together"),
 		},
 	}
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			mockstore := mocks.NewMockstore(ctrl)
+			mocks := initJobMocks{
+				mockStore: mockstore,
+			}
+			if tc.setupMocks != nil {
+				tc.setupMocks(mocks)
+			}
 			opts := initJobOpts{
 				initJobVars: initJobVars{
 					initWkldVars: initWkldVars{
@@ -157,11 +144,12 @@ func TestJobInitOpts_Validate(t *testing.T) {
 						image:          tc.inImage,
 						dockerfilePath: tc.inDockerfilePath,
 					},
-					timeout:  tc.inTimeout,
-					retries:  tc.inRetries,
-					schedule: tc.inSchedule,
+					timeout: tc.inTimeout,
+					retries: tc.inRetries,
 				},
-				fs: &afero.Afero{Fs: afero.NewMemMapFs()},
+				store:     mockstore,
+				fs:        &afero.Afero{Fs: afero.NewMemMapFs()},
+				wsAppName: "phonetool",
 			}
 			if tc.mockFileSystem != nil {
 				tc.mockFileSystem(opts.fs)
@@ -201,6 +189,15 @@ func TestJobInitOpts_Ask(t *testing.T) {
 		wantedErr      error
 		wantedSchedule string
 	}{
+		"invalid job type": {
+			inJobType: "TestJobType",
+			wantedErr: errors.New(`invalid job type TestJobType: must be one of "Scheduled Job"`),
+		},
+		"invalid job name": {
+			inJobType: wantedJobType,
+			inJobName: "1234",
+			wantedErr: fmt.Errorf("job name 1234 is invalid: %s", errValueBadFormat),
+		},
 		"error if fail to get job name": {
 			inJobType:        wantedJobType,
 			inJobName:        "",
@@ -209,10 +206,10 @@ func TestJobInitOpts_Ask(t *testing.T) {
 
 			setupMocks: func(m initJobMocks) {
 				m.mockPrompt.EXPECT().Get(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
-					Return("", errors.New("some error"))
+					Return("", mockError)
 			},
 
-			wantedErr: fmt.Errorf("get job name: some error"),
+			wantedErr: fmt.Errorf("get job name: mock error"),
 		},
 		"returns an error if job already exists": {
 			inJobType:        wantedJobType,
@@ -264,11 +261,23 @@ func TestJobInitOpts_Ask(t *testing.T) {
 			inJobSchedule:    wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, mockError)
 			},
 
 			wantedErr: fmt.Errorf("read manifest file for job cuteness-aggregator: mock error"),
 		},
+		"error if manifest type doesn't match": {
+			inJobType: "Scheduled Job",
+			inJobName: wantedJobName,
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
+				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return([]byte(`
+type: Backend Service`), nil)
+			},
+			wantedErr: fmt.Errorf("manifest file for job cuteness-aggregator exists with a different type Backend Service"),
+		},
 		"skip asking questions if local manifest file exists": {
 			inJobType:        wantedJobType,
 			inJobName:        wantedJobName,
@@ -276,6 +285,7 @@ func TestJobInitOpts_Ask(t *testing.T) {
 			inJobSchedule:    wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return([]byte(`name: cuteness-aggregator
 type: Scheduled Job`), nil)
 			},
@@ -290,6 +300,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule:    wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 			},
 
@@ -301,6 +312,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule: wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockDockerEngine.EXPECT().CheckDockerEngineRunning().Return(errors.New("some error"))
 			},
@@ -313,6 +325,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule: wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockPrompt.EXPECT().Get(wkldInitImagePrompt, wkldInitImagePromptHelp, gomock.Any(), gomock.Any()).
 					Return("mockImage", nil)
@@ -327,6 +340,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule: wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockPrompt.EXPECT().Get(wkldInitImagePrompt, wkldInitImagePromptHelp, gomock.Any(), gomock.Any()).
 					Return("mockImage", nil)
@@ -341,6 +355,7 @@ type: Scheduled Job`), nil)
 			inDockerfilePath: "",
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockPrompt.EXPECT().Get(wkldInitImagePrompt, wkldInitImagePromptHelp, gomock.Any(), gomock.Any()).
 					Return("", mockError)
@@ -363,6 +378,7 @@ type: Scheduled Job`), nil)
 			inDockerfilePath: "",
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockPrompt.EXPECT().Get(wkldInitImagePrompt, wkldInitImagePromptHelp, gomock.Any(), gomock.Any()).
 					Return("mockImage", nil)
@@ -385,6 +401,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule:    wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockSel.EXPECT().Dockerfile(
 					gomock.Eq(fmt.Sprintf(fmtWkldInitDockerfilePrompt, color.HighlightUserInput(wantedJobName))),
@@ -405,6 +422,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule:    wantedCronSchedule,
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockSel.EXPECT().Dockerfile(
 					gomock.Eq(fmt.Sprintf(fmtWkldInitDockerfilePrompt, color.HighlightUserInput(wantedJobName))),
@@ -425,6 +443,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule:    "",
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrWorkspaceNotFound{})
 				m.mockSel.EXPECT().Schedule(
 					gomock.Eq(jobInitSchedulePrompt),
@@ -443,6 +462,7 @@ type: Scheduled Job`), nil)
 			inJobSchedule:    "",
 
 			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
 				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
 				m.mockSel.EXPECT().Schedule(
 					gomock.Any(),
@@ -454,6 +474,19 @@ type: Scheduled Job`), nil)
 
 			wantedErr: fmt.Errorf("get schedule: some error"),
 		},
+		"valid schedule": {
+			inJobType:        wantedJobType,
+			inJobName:        wantedJobName,
+			inDockerfilePath: wantedDockerfilePath,
+			inJobSchedule:    wantedCronSchedule,
+
+			setupMocks: func(m initJobMocks) {
+				m.mockStore.EXPECT().GetJob(mockAppName, wantedJobName).Return(nil, &config.ErrNoSuchJob{})
+				m.mockMftReader.EXPECT().ReadWorkloadManifest(wantedJobName).Return(nil, &workspace.ErrFileNotExists{FileName: wantedJobName})
+			},
+
+			wantedSchedule: wantedCronSchedule,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -473,7 +506,10 @@ type: Scheduled Job`), nil)
 				mockMftReader:    mockManifestReader,
 				mockStore:        mockStore,
 			}
-			tc.setupMocks(mocks)
+			if tc.setupMocks != nil {
+				tc.setupMocks(mocks)
+			}
+
 			opts := &initJobOpts{
 				initJobVars: initJobVars{
 					initWkldVars: initWkldVars{
@@ -638,3 +674,69 @@ func TestJobInitOpts_Execute(t *testing.T) {
 		})
 	}
 }
+
+func Test_ValidateSchedule(t *testing.T) {
+	testCases := map[string]struct {
+		inSchedule string
+
+		wantedErr error
+	}{
+		"invalid schedule; not cron": {
+			inSchedule: "every 56 minutes",
+			wantedErr:  fmt.Errorf("schedule every 56 minutes is invalid: %s", errScheduleInvalid),
+		},
+		"invalid schedule; cron interval in subseconds": {
+			inSchedule: "@every 75.9s",
+			wantedErr:  fmt.Errorf("interval @every 75.9s is invalid: %s", errDurationBadUnits),
+		},
+		"invalid schedule; cron interval in milliseconds": {
+			inSchedule: "@every 3ms",
+			wantedErr:  fmt.Errorf("interval @every 3ms is invalid: %s", errDurationBadUnits),
+		},
+		"invalid schedule; cron interval too frequent": {
+			inSchedule: "@every 30s",
+			wantedErr:  errors.New("interval @every 30s is invalid: duration must be 1m0s or greater"),
+		},
+		"invalid schedule; cron interval is zero": {
+			inSchedule: "@every 0s",
+			wantedErr:  errors.New("interval @every 0s is invalid: duration must be 1m0s or greater"),
+		},
+		"invalid schedule; cron interval duration improperly formed": {
+			inSchedule: "@every 5min",
+			wantedErr:  errors.New("interval @every 5min must include a valid Go duration string (example: @every 1h30m)"),
+		},
+		"valid schedule; crontab": {
+			inSchedule: "* * * * *",
+			wantedErr:  nil,
+		},
+		"valid schedule; predefined schedule": {
+			inSchedule: "@daily",
+			wantedErr:  nil,
+		},
+		"valid schedule; interval": {
+			inSchedule: "@every 5m",
+			wantedErr:  nil,
+		},
+		"valid schedule; interval with 0 for some units": {
+			inSchedule: "@every 1h0m0s",
+			wantedErr:  nil,
+		},
+		"valid schedule; interval with carryover value for some units": {
+			inSchedule: "@every 0h60m60s",
+			wantedErr:  nil,
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// WHEN
+			err := validateSchedule(tc.inSchedule)
+			// THEN
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
