@@ -21,6 +21,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+var (
+	testPrivatePlacement = manifest.PrivateSubnetPlacement
+)
+
 var testRDWebServiceManifest = &manifest.RequestDrivenWebService{
 	Workload: manifest.Workload{
 		Name: aws.String(testServiceName),
@@ -221,7 +225,7 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 	}{
 		"should throw an error if env controller cannot be parsed": {
 			inManifest: func(mft manifest.RequestDrivenWebService) manifest.RequestDrivenWebService {
-				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&manifest.PrivateSubnetPlacement)
+				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&testPrivatePlacement)
 				return mft
 			},
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
@@ -243,7 +247,7 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 		"should be able to parse custom resource URLs when alias is enabled": {
 			inManifest: func(mft manifest.RequestDrivenWebService) manifest.RequestDrivenWebService {
 				mft.Alias = aws.String("convex.domain.com")
-				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&manifest.PrivateSubnetPlacement)
+				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&testPrivatePlacement)
 				return mft
 			},
 			inCustomResourceURLs: map[string]string{
