@@ -7,13 +7,14 @@ package deploy
 
 import (
 	"github.com/aws/copilot-cli/internal/pkg/config"
+	"github.com/aws/copilot-cli/internal/pkg/manifest"
 )
 
 const (
 	// LegacyEnvTemplateVersion is the version associated with the environment template before we started versioning.
 	LegacyEnvTemplateVersion = "v0.0.0"
 	// LatestEnvTemplateVersion is the latest version number available for environment templates.
-	LatestEnvTemplateVersion = "v1.8.0"
+	LatestEnvTemplateVersion = "v1.9.0"
 )
 
 // CreateEnvironmentInput holds the fields required to deploy an environment.
@@ -30,7 +31,9 @@ type CreateEnvironmentInput struct {
 	CustomResourcesURLs  map[string]string // Environment custom resource script S3 object URLs.
 	ImportVPCConfig      *config.ImportVPC // Optional configuration if users have an existing VPC.
 	AdjustVPCConfig      *config.AdjustVPC // Optional configuration if users want to override default VPC configuration.
+	ImportCertARNs       []string          // Optional configuration if users want to import certificates.
 	Telemetry            *config.Telemetry // Optional observability and monitoring configuration.
+	Mft                  *manifest.Environment
 
 	CFNServiceRoleARN string // Optional. A service role ARN that CloudFormation should use to make calls to resources in the stack.
 }
