@@ -305,6 +305,25 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 			},
 			wantedError: errors.New(`scaling based on "nlb" requests or response time is not supported`),
 		},
+		"error if fail to validate deployment": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
+					DeployConfig: DeploymentConfiguration{
+						Rolling: aws.String("mockName"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "deployment"`,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -465,6 +484,29 @@ func TestBackendService_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate ARM: `,
 		},
+		"error if fail to validate deployment": {
+			config: BackendService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				BackendServiceConfig: BackendServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/arm64"))},
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Spot:         aws.Int(123),
+								workloadType: BackendServiceType,
+							},
+						},
+					},
+					DeployConfig: DeploymentConfiguration{
+						Rolling: aws.String("mockName"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "deployment":`,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -551,6 +593,25 @@ func TestRequestDrivenWebService_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate "network": `,
 		},
+		"error if fail to validate observability": {
+			config: RequestDrivenWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
+					ImageConfig: ImageWithPort{
+						Image: Image{
+							Location: stringP("mockLocation"),
+						},
+						Port: uint16P(80),
+					},
+					Observability: Observability{
+						Tracing: aws.String("unknown-vendor"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "observability": `,
+		},
 		"error if name is not set": {
 			config: RequestDrivenWebService{
 				RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
@@ -734,6 +795,29 @@ func TestWorkerService_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate ARM: `,
 		},
+		"error if fail to validate deployment": {
+			config: WorkerService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				WorkerServiceConfig: WorkerServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/arm64"))},
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Spot:         aws.Int(123),
+								workloadType: WorkerServiceType,
+							},
+						},
+					},
+					DeployConfig: DeploymentConfiguration{
+						Rolling: aws.String("mockName"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "deployment":`,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -913,6 +997,89 @@ func TestScheduledJob_Validate(t *testing.T) {
 	}
 }
 
+func TestPipelineManifest_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		Pipeline Pipeline
+
+		wantedError          error
+		wantedErrorMsgPrefix string
+	}{
+		"error if name exceeds 100 characters": {
+			Pipeline: Pipeline{
+				Name: "12345678902234567890323456789042345678905234567890623456789072345678908234567890923456789010234567890",
+			},
+			wantedError: errors.New("pipeline name '12345678902234567890323456789042345678905234567890623456789072345678908234567890923456789010234567890' must be shorter than 100 characters"),
+		},
+		"should validate pipeline stages": {
+			Pipeline: Pipeline{
+				Name: "release",
+				Stages: []PipelineStage{
+					{
+						Name: "test",
+						Deployments: map[string]*Deployment{
+							"frontend": {
+								DependsOn: []string{"backend"},
+							},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "deployments" for pipeline stage test:`,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.Pipeline.Validate()
+
+			switch {
+			case tc.wantedError != nil:
+				require.EqualError(t, gotErr, tc.wantedError.Error())
+			case tc.wantedErrorMsgPrefix != "":
+				require.Error(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
+			default:
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
+func TestDeployments_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		in     Deployments
+		wanted error
+	}{
+		"should return nil on empty deployments": {},
+		"should return an error when a dependency does not exist": {
+			in: map[string]*Deployment{
+				"frontend": {
+					DependsOn: []string{"backend"},
+				},
+			},
+			wanted: errors.New("dependency deployment named 'backend' of 'frontend' does not exist"),
+		},
+		"should return nil when all dependencies are present": {
+			in: map[string]*Deployment{
+				"frontend": {
+					DependsOn: []string{"backend"},
+				},
+				"backend": nil,
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			actual := tc.in.Validate()
+
+			if tc.wanted == nil {
+				require.NoError(t, actual)
+			} else {
+				require.EqualError(t, actual, tc.wanted.Error())
+			}
+		})
+	}
+}
+
 func TestImageWithPort_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		ImageWithPort ImageWithPort
@@ -2112,6 +2279,40 @@ func TestAppRunnerInstanceConfig_Validate(t *testing.T) {
 	}
 }
 
+func TestObservability_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		config            Observability
+		wantedErrorPrefix string
+	}{
+		"error if tracing has invalid vendor": {
+			config: Observability{
+				Tracing: aws.String("unknown-vendor"),
+			},
+			wantedErrorPrefix: `invalid tracing vendor unknown-vendor: `,
+		},
+		"ok if tracing is aws-xray": {
+			config: Observability{
+				Tracing: aws.String("awsxray"),
+			},
+		},
+		"ok if observability is empty": {
+			config: Observability{},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.config.Validate()
+
+			if tc.wantedErrorPrefix != "" {
+				require.NotNil(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wantedErrorPrefix)
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
 func TestJobTriggerConfig_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		in     *JobTriggerConfig
@@ -2560,3 +2761,42 @@ func TestValidateARM(t *testing.T) {
 		})
 	}
 }
+
+func TestDeploymentConfiguration_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		deployConfig DeploymentConfiguration
+		wanted       string
+	}{
+		"error if deploy config has invalid rolling strategy": {
+			deployConfig: DeploymentConfiguration{
+				Rolling: aws.String("unknown"),
+			},
+			wanted: `invalid rolling deployment strategy unknown, must be one of default or recreate`,
+		},
+		"ok if deployment strategy is recreate": {
+			deployConfig: DeploymentConfiguration{
+				Rolling: aws.String("recreate"),
+			},
+		},
+		"ok if deployment strategy is default": {
+			deployConfig: DeploymentConfiguration{
+				Rolling: aws.String("default"),
+			},
+		},
+		"ok if deployment is empty": {
+			deployConfig: DeploymentConfiguration{},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.deployConfig.Validate()
+
+			if tc.wanted != "" {
+				require.NotNil(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wanted)
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
