@@ -28,28 +28,34 @@ type Registry interface {
 type Repository struct {
 	name     string
 	registry Registry
-
-	uri string
+	uri      string
 }
 
 // New instantiates a new Repository.
-func New(name string, registry Registry) (*Repository, error) {
-	uri, err := registry.RepositoryURI(name)
-	if err != nil {
-		return nil, fmt.Errorf("get repository URI: %w", err)
-	}
-
+func New(registry Registry, name string) *Repository {
 	return &Repository{
 		name:     name,
-		uri:      uri,
 		registry: registry,
-	}, nil
+	}
+}
+
+// NewWithURI instantiates a new Repository with uri being set.
+func NewWithURI(registry Registry, name, uri string) *Repository {
+	return &Repository{
+		name:     name,
+		registry: registry,
+		uri:      uri,
+	}
 }
 
 // BuildAndPush builds the image from Dockerfile and pushes it to the repository with tags.
 func (r *Repository) BuildAndPush(docker ContainerLoginBuildPusher, args *dockerengine.BuildArguments) (digest string, err error) {
 	if args.URI == "" {
-		args.URI = r.uri
+		uri, err := r.URI()
+		if err != nil {
+			return "", err
+		}
+		args.URI = uri
 	}
 	if err := docker.Build(args); err != nil {
 		return "", fmt.Errorf("build Dockerfile at %s: %w", args.Dockerfile, err)
@@ -75,6 +81,13 @@ func (r *Repository) BuildAndPush(docker ContainerLoginBuildPusher, args *docker
 }
 
 // URI returns the uri of the repository.
-func (r *Repository) URI() string {
-	return r.uri
+func (r *Repository) URI() (string, error) {
+	if r.uri != "" {
+		return r.uri, nil
+	}
+	uri, err := r.registry.RepositoryURI(r.name)
+	if err != nil {
+		return "", fmt.Errorf("get repository URI: %w", err)
+	}
+	return uri, nil
 }
