@@ -80,10 +80,11 @@ func TestEnvRunner_Run(t *testing.T) {
 	}
 
 	testCases := map[string]struct {
-		count     int
-		groupName string
-		os        string
-		arch      string
+		count          int
+		groupName      string
+		os             string
+		arch           string
+		securityGroups []string
 
 		MockVPCGetter            func(m *mocks.MockVPCGetter)
 		MockClusterGetter        func(m *mocks.MockClusterGetter)
@@ -140,6 +141,17 @@ func TestEnvRunner_Run(t *testing.T) {
 			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
 			wantedError:              fmt.Errorf(fmtErrSecurityGroupsFromEnv, inEnv, errors.New("error getting security groups")),
 		},
+		"failed with too many security groups": {
+			securityGroups: []string{"sg-2", "sg-3", "sg-4", "sg-5", "sg-6"},
+
+			MockClusterGetter: mockClusterGetter,
+			MockVPCGetter: func(m *mocks.MockVPCGetter) {
+				m.EXPECT().SecurityGroups(filtersForSecurityGroup).Return([]string{"sg-1", "sg-2"}, nil)
+			},
+			mockStarter:              mockStarterNotRun,
+			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
+			wantedError:              fmt.Errorf(fmtErrNumSecurityGroups, 6, "sg-1,sg-2,sg-3,sg-4,sg-5,sg-6"),
+		},
 		"failed to kick off task": {
 			count:     1,
 			groupName: "my-task",
@@ -194,6 +206,35 @@ func TestEnvRunner_Run(t *testing.T) {
 				},
 			},
 		},
+		"run in env with extra security groups success": {
+			count:          1,
+			groupName:      "my-task",
+			securityGroups: []string{"sg-1", "sg-extra"},
+
+			MockClusterGetter: mockClusterGetter,
+			MockVPCGetter: func(m *mocks.MockVPCGetter) {
+				m.EXPECT().SecurityGroups(filtersForSecurityGroup).Return([]string{"sg-1", "sg-2"}, nil)
+			},
+			mockStarter: func(m *mocks.MockRunner) {
+				m.EXPECT().RunTask(ecs.RunTaskInput{
+					Cluster:         "cluster-1",
+					Count:           1,
+					Subnets:         []string{"subnet-0789ab", "subnet-0123cd"},
+					SecurityGroups:  []string{"sg-1", "sg-2", "sg-extra"},
+					TaskFamilyName:  taskFamilyName("my-task"),
+					StartedBy:       startedBy,
+					PlatformVersion: "LATEST",
+					EnableExec:      true,
+				}).Return([]*ecs.Task{&taskWithENI}, nil)
+			},
+			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
+			wantedTasks: []*Task{
+				{
+					TaskARN: "task-1",
+					ENI:     "eni-1",
+				},
+			},
+		},
 		"run in env with windows os success": {
 			count:     1,
 			groupName: "my-task",
@@ -287,6 +328,8 @@ func TestEnvRunner_Run(t *testing.T) {
 
 				OS: tc.os,
 
+				SecurityGroups: tc.securityGroups,
+
 				VPCGetter:            MockVPCGetter,
 				ClusterGetter:        MockClusterGetter,
 				Starter:              mockStarter,
