@@ -7,10 +7,14 @@
 //  .
 //  ├── copilot                        (application directory)
 //  │   ├── .workspace                 (workspace summary)
-//  │   └── my-service
+//  │   ├── my-service
 //  │   │   └── manifest.yml           (service manifest)
-//  │   ├── buildspec.yml              (buildspec for the pipeline's build stage)
-//  │   └── pipeline.yml               (pipeline manifest)
+//  │   ├── buildspec.yml              (legacy buildspec for the pipeline's build stage)
+//  │   ├── pipeline.yml               (legacy pipeline manifest)
+//  │   ├── pipelines
+//  │   │   ├── pipeline-app-beta
+//  │   │   │   ├── buildspec.yml      (buildspec for the pipeline 'pipeline-app-beta')
+//  │   ┴   ┴   └── manifest.yml       (pipeline manifest for the pipeline 'pipeline-app-beta')
 //  └── my-service-src                 (customer service code)
 package workspace
 
@@ -23,6 +27,8 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/aws/copilot-cli/internal/pkg/term/log"
+
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/spf13/afero"
 	"gopkg.in/yaml.v3"
@@ -35,19 +41,23 @@ const (
 	SummaryFileName = ".workspace"
 
 	addonsDirName             = "addons"
+	pipelinesDirName          = "pipelines"
 	maximumParentDirsToSearch = 5
-	pipelineFileName          = "pipeline.yml"
+	legacyPipelineFileName    = "pipeline.yml"
 	manifestFileName          = "manifest.yml"
 	buildspecFileName         = "buildspec.yml"
 
 	ymlFileExtension = ".yml"
 
-	dockerfileName = "dockerfile"
+	dockerfileName   = "dockerfile"
+	dockerignoreName = ".dockerignore"
 )
 
 // Summary is a description of what's associated with this workspace.
 type Summary struct {
 	Application string `yaml:"application"` // Name of the application.
+
+	Path string // absolute path to the summary file.
 }
 
 // Workspace typically represents a Git repository where the user has its infrastructure-as-code files as well as source files.
@@ -55,12 +65,14 @@ type Workspace struct {
 	workingDir string
 	copilotDir string
 	fsUtils    *afero.Afero
+	logger     func(format string, args ...interface{})
 }
 
 // New returns a workspace, used for reading and writing to user's local workspace.
 func New() (*Workspace, error) {
 	fs := afero.NewOsFs()
 	fsUtils := &afero.Afero{Fs: fs}
+	logger := log.Infof
 
 	workingDir, err := os.Getwd()
 	if err != nil {
@@ -69,6 +81,7 @@ func New() (*Workspace, error) {
 	ws := Workspace{
 		workingDir: workingDir,
 		fsUtils:    fsUtils,
+		logger:     logger,
 	}
 
 	return &ws, nil
@@ -87,7 +100,11 @@ func (ws *Workspace) Create(appName string) error {
 	if err == nil {
 		// If a summary exists, but is registered to a different application, throw an error.
 		if summary.Application != appName {
-			return &errHasExistingApplication{existingAppName: summary.Application}
+			return &errHasExistingApplication{
+				existingAppName: summary.Application,
+				basePath:        ws.workingDir,
+				summaryPath:     summary.Path,
+			}
 		}
 		// Otherwise our work is all done.
 		return nil
@@ -114,7 +131,9 @@ func (ws *Workspace) Summary() (*Summary, error) {
 		if err != nil {
 			return nil, err
 		}
-		wsSummary := Summary{}
+		wsSummary := Summary{
+			Path: summaryPath,
+		}
 		return &wsSummary, yaml.Unmarshal(value, &wsSummary)
 	}
 	return nil, &errNoAssociatedApplication{}
@@ -144,13 +163,81 @@ func (ws *Workspace) ListJobs() ([]string, error) {
 	})
 }
 
-// ListWorkloads returns the name of all the workloads in the workspace.
+// ListWorkloads returns the name of all the workloads in the workspace (could be unregistered in SSM).
 func (ws *Workspace) ListWorkloads() ([]string, error) {
 	return ws.listWorkloads(func(wlType string) bool {
 		return true
 	})
 }
 
+// PipelineManifest holds identifying information about a pipeline manifest file.
+type PipelineManifest struct {
+	Name string // Name of the pipeline inside the manifest file.
+	Path string // Absolute path to the manifest file for the pipeline.
+}
+
+// ListPipelines returns all pipelines in the workspace.
+func (ws *Workspace) ListPipelines() ([]PipelineManifest, error) {
+	var manifests []PipelineManifest
+
+	addManifest := func(manifestPath string) {
+		manifest, err := ws.ReadPipelineManifest(manifestPath)
+		switch {
+		case errors.Is(err, ErrNoPipelineInWorkspace):
+			// no file at manifestPath, ignore it
+			return
+		case err != nil:
+			ws.logger("Unable to read pipeline manifest at '%s': %s\n", manifestPath, err)
+			return
+		}
+
+		manifests = append(manifests, PipelineManifest{
+			Name: manifest.Name,
+			Path: manifestPath,
+		})
+	}
+
+	// add the legacy pipeline
+	legacyPath, err := ws.pipelineManifestLegacyPath()
+	if err != nil {
+		return nil, err
+	}
+	addManifest(legacyPath)
+
+	// add each file that matches pipelinesDir/*/manifest.yml
+	pipelinesDir, err := ws.pipelinesDirPath()
+	if err != nil {
+		return nil, err
+	}
+
+	exists, err := ws.fsUtils.Exists(pipelinesDir)
+	switch {
+	case err != nil:
+		return nil, fmt.Errorf("check if pipelines directory exists at %q: %w", pipelinesDir, err)
+	case !exists:
+		// there is at most 1 manifest (the legacy one), so we don't need to sort
+		return manifests, nil
+	}
+
+	files, err := ws.fsUtils.ReadDir(pipelinesDir)
+	if err != nil {
+		return nil, fmt.Errorf("read directory %q: %w", pipelinesDir, err)
+	}
+
+	for _, dir := range files {
+		if dir.IsDir() {
+			addManifest(filepath.Join(pipelinesDir, dir.Name(), manifestFileName))
+		}
+	}
+
+	// sort manifests alphabetically by Name
+	sort.Slice(manifests, func(i, j int) bool {
+		return manifests[i].Name < manifests[j].Name
+	})
+
+	return manifests, nil
+}
+
 // listWorkloads returns the name of all workloads (either services or jobs) in the workspace.
 func (ws *Workspace) listWorkloads(match func(string) bool) ([]string, error) {
 	copilotPath, err := ws.copilotDirPath()
@@ -202,21 +289,24 @@ func (ws *Workspace) ReadWorkloadManifest(mftDirName string) (WorkloadManifest,
 	return mft, nil
 }
 
-// ReadPipelineManifest returns the contents of the pipeline manifest under copilot/pipeline.yml.
-func (ws *Workspace) ReadPipelineManifest() ([]byte, error) {
-	pmPath, err := ws.pipelineManifestPath()
-	if err != nil {
-		return nil, err
-	}
-	manifestExists, err := ws.fsUtils.Exists(pmPath)
-
+// ReadPipelineManifest returns the contents of the pipeline manifest under the given path.
+func (ws *Workspace) ReadPipelineManifest(path string) (*manifest.Pipeline, error) {
+	manifestExists, err := ws.fsUtils.Exists(path)
 	if err != nil {
 		return nil, err
 	}
 	if !manifestExists {
 		return nil, ErrNoPipelineInWorkspace
 	}
-	return ws.read(pipelineFileName)
+	data, err := ws.fsUtils.ReadFile(path)
+	if err != nil {
+		return nil, fmt.Errorf("read pipeline manifest: %w", err)
+	}
+	pipelineManifest, err := manifest.UnmarshalPipeline(data)
+	if err != nil {
+		return nil, fmt.Errorf("unmarshal pipeline manifest: %w", err)
+	}
+	return pipelineManifest, nil
 }
 
 // WriteServiceManifest writes the service's manifest under the copilot/{name}/ directory.
@@ -237,24 +327,24 @@ func (ws *Workspace) WriteJobManifest(marshaler encoding.BinaryMarshaler, name s
 	return ws.write(data, name, manifestFileName)
 }
 
-// WritePipelineBuildspec writes the pipeline buildspec under the copilot/ directory.
+// WritePipelineBuildspec writes the pipeline buildspec under the copilot/pipelines/{name}/ directory.
 // If successful returns the full path of the file, otherwise returns an empty string and the error.
-func (ws *Workspace) WritePipelineBuildspec(marshaler encoding.BinaryMarshaler) (string, error) {
+func (ws *Workspace) WritePipelineBuildspec(marshaler encoding.BinaryMarshaler, name string) (string, error) {
 	data, err := marshaler.MarshalBinary()
 	if err != nil {
 		return "", fmt.Errorf("marshal pipeline buildspec to binary: %w", err)
 	}
-	return ws.write(data, buildspecFileName)
+	return ws.write(data, pipelinesDirName, name, buildspecFileName)
 }
 
-// WritePipelineManifest writes the pipeline manifest under the copilot directory.
+// WritePipelineManifest writes the pipeline manifest under the copilot/pipelines/{name}/ directory.
 // If successful returns the full path of the file, otherwise returns an empty string and the error.
-func (ws *Workspace) WritePipelineManifest(marshaler encoding.BinaryMarshaler) (string, error) {
+func (ws *Workspace) WritePipelineManifest(marshaler encoding.BinaryMarshaler, name string) (string, error) {
 	data, err := marshaler.MarshalBinary()
 	if err != nil {
 		return "", fmt.Errorf("marshal pipeline manifest to binary: %w", err)
 	}
-	return ws.write(data, pipelineFileName)
+	return ws.write(data, pipelinesDirName, name, manifestFileName)
 }
 
 // DeleteWorkspaceFile removes the .workspace file under copilot/ directory.
@@ -308,6 +398,15 @@ func IsInGitRepository(fs FileStat) bool {
 	return !os.IsNotExist(err)
 }
 
+// pipelineManifestLegacyPath returns the path to pipeline manifests before multiple pipelines (and the copilot/pipelines/ dir) were enabled.
+func (ws *Workspace) pipelineManifestLegacyPath() (string, error) {
+	copilotPath, err := ws.copilotDirPath()
+	if err != nil {
+		return "", err
+	}
+	return filepath.Join(copilotPath, legacyPipelineFileName), nil
+}
+
 func (ws *Workspace) writeSummary(appName string) error {
 	summaryPath, err := ws.summaryPath()
 	if err != nil {
@@ -326,13 +425,12 @@ func (ws *Workspace) writeSummary(appName string) error {
 	return ws.fsUtils.WriteFile(summaryPath, serializedWorkspaceSummary, 0644)
 }
 
-func (ws *Workspace) pipelineManifestPath() (string, error) {
+func (ws *Workspace) pipelinesDirPath() (string, error) {
 	copilotPath, err := ws.copilotDirPath()
 	if err != nil {
 		return "", err
 	}
-	pipelineManifestPath := filepath.Join(copilotPath, pipelineFileName)
-	return pipelineManifestPath, nil
+	return filepath.Join(copilotPath, pipelinesDirName), nil
 }
 
 func (ws *Workspace) summaryPath() (string, error) {
@@ -362,6 +460,15 @@ func (ws *Workspace) Path() (string, error) {
 	return filepath.Dir(copilotDirPath), nil
 }
 
+// Rel returns the path relative to the workspace root.
+func (ws *Workspace) Rel(fullPath string) (string, error) {
+	copiDir, err := ws.copilotDirPath()
+	if err != nil {
+		return "", fmt.Errorf("get path to Copilot dir: %w", err)
+	}
+	return filepath.Rel(filepath.Dir(copiDir), fullPath)
+}
+
 func (ws *Workspace) copilotDirPath() (string, error) {
 	if ws.copilotDir != "" {
 		return ws.copilotDir, nil
@@ -449,7 +556,7 @@ func (ws *Workspace) ListDockerfiles() ([]string, error) {
 		// Add current file if it is a Dockerfile and not a directory; otherwise continue.
 		if !wdFile.IsDir() {
 			fname := wdFile.Name()
-			if strings.Contains(strings.ToLower(fname), dockerfileName) {
+			if strings.Contains(strings.ToLower(fname), dockerfileName) && !strings.HasSuffix(strings.ToLower(fname), dockerignoreName) {
 				path := filepath.Dir(fname) + "/" + fname
 				dockerfiles = append(dockerfiles, path)
 			}
@@ -468,7 +575,7 @@ func (ws *Workspace) ListDockerfiles() ([]string, error) {
 				continue
 			}
 			fname := f.Name()
-			if strings.Contains(strings.ToLower(fname), dockerfileName) {
+			if strings.Contains(strings.ToLower(fname), dockerfileName) && !strings.HasSuffix(strings.ToLower(fname), dockerignoreName) {
 				path := wdFile.Name() + "/" + f.Name()
 				dockerfiles = append(dockerfiles, path)
 			}
@@ -478,19 +585,6 @@ func (ws *Workspace) ListDockerfiles() ([]string, error) {
 	return dockerfiles, nil
 }
 
-// RelPath returns the path relative to the current working directory.
-func RelPath(fullPath string) (string, error) {
-	wkdir, err := os.Getwd()
-	if err != nil {
-		return "", fmt.Errorf("get working directory: %w", err)
-	}
-	path, err := filepath.Rel(wkdir, fullPath)
-	if err != nil {
-		return "", fmt.Errorf("get relative path of file: %w", err)
-	}
-	return path, nil
-}
-
 // WorkloadManifest represents raw local workload manifest.
 type WorkloadManifest []byte
 
